@@ -23,7 +23,7 @@ def generate_choices():
 
 def generate_ts():
     choices = generate_choices()
-    ts_var_name = getattr(settings, 'DJANGO_TS_BRDIGE_CHOICE_VAR_NAME', default_settings.DJANGO_TS_BRIDGE_CHOICE_VAR_NAME)
+    ts_var_name = getattr(settings, 'DJANGO_TS_BRIDGE_CHOICE_VAR_NAME', default_settings.DJANGO_TS_BRIDGE_CHOICE_VAR_NAME)
     ts_content = loader.render_to_string(
         'django_ts_bridge/choices_ts.tpl',
         {
